<template>
  <a-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    :maskClosable="false"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">

        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="规则编码"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请输入规则编码"
                v-decorator="['ruleCode', validatorRules.ruleCode ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="规则名称"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请输入规则名称"
                v-decorator="['ruleName', validatorRules.ruleName ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="{ span: 3 }" 
              :wrapperCol="{ span: 21 }"
              label="规则分类"
            >
              <j-dict-select-tag  
                :disabled="disableSubmit"
                placeholder="请输入规则分类"
                v-decorator="['ruleCategory', validatorRules.ruleCategory ]"
                dictCode="rule_category"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="抽样数量"
            >
              <a-input-number :disabled="disableSubmit" v-decorator="['samplingQuantity', validatorRules.samplingQuantity ]" :min="1" style="width: 100%" placeholder="请输入抽样数量" />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="最大不合格数"
            >
              <a-input-number :disabled="disableSubmit" v-decorator="['maxUnqualifiedQuantity', validatorRules.maxUnqualifiedQuantity ]" :min="1" style="width: 100%" placeholder="请输入最大不合格数" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="批量下限值"
            >
              <a-input-number :disabled="disableSubmit" v-decorator="['batchLowerLimit', validatorRules.batchLowerLimit ]" :min="1" style="width: 100%" placeholder="请输入批量下限值" />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="批量上限值"
            >
              <a-input-number :disabled="disableSubmit" v-decorator="['batchUpperLimit', validatorRules.batchUpperLimit ]" :min="1" style="width: 100%" placeholder="请输入批量上限值" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="{ span: 3 }" 
              :wrapperCol="{ span: 21 }"
              label="备注"
            >
            <a-textarea :disabled="disableSubmit" placeholder="请输入备注" v-decorator="['remark', validatorRules.remark ]"/>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
  </a-modal>
</template>

<script>
import { httpAction, getAction } from '@/api/manage'
import pick from 'lodash.pick'
import { duplicateCheck } from '@/api/api'//重复校验
import JDictSelectTag from '../../../../components/dict/JDictSelectTag.vue'

export default {
  components: { JDictSelectTag },
  name: "SamplingRulesModal",
  data() {
    return {
      title: "操作",
      visible: false,
      disableSubmit: false,
      model: {},
      samplingRulesId: "", //保存抽样规则id
      labelCol: {
          xs: { span: 24 },
          sm: { span: 6 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 18 },
        },

      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        ruleCode: {
          rules: [
            { required: true, message: '请输入规则编码' },
            { validator: this.validateNum },
          ]
        },
        ruleName: {
          rules: [
            { required: true, message: '请输入规则名称' },
            { validator: this.validateName },
          ]
        },
         ruleCategory: {
          rules: [
            { required: true, message: '请选择规则分类' },
          ]
        },
      },
      url: {
        add: "/qms/samplingRules/add",
        edit: "/qms/samplingRules/edit",
      },
    }
  },
  created() {
  },
  methods: {
    add() {
      this.edit({});
    },
    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.samplingRulesId = record.id;
      this.visible = true;
      this.$nextTick(() => {
        this.form.setFieldsValue(
          pick(this.model, 'ruleCode', 'ruleName','ruleCategory','ruleStatus','maxUnqualifiedQuantity',
          'samplingQuantity','batchLowerLimit','batchUpperLimit', 'remark')
        )
      });
    },
    close() {
      this.$emit('close');
      this.visible = false;
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          let formData = Object.assign(this.model, values);
          httpAction(httpurl, formData, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },
    handleCancel() {
      this.close()
    },
    //验证 编号
    validateNum(rule, value, callback) {
      var params = {
        tableName: 'qms_sampling_rules',
        fieldName: 'rule_code',
        fieldVal: value,
        dataId: this.samplingRulesId,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("规则编码已存在!");
        }
      })
    },
    //验证 名称
    validateName(rule, value, callback) {
      var params = {
        tableName: 'qms_sampling_rules',
        fieldName: 'rule_name',
        fieldVal: value,
        dataId: this.samplingRulesId,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("规则名称已存在!");
        }
      })
    },
    // 关闭弹窗时清除表单校验
    removeValidate() {
      if (this.$refs.form) this.$refs.form.clearValidate()
    }
  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>